<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="html"/>

<!-- trasforma un xml contenente una descrizione di record in righe di edit -->
<!-- esempio :
  questo xml:
  <tbledit>
    <field set='0' post='S' id='codice' label='Reparto' type='number' mandatory>
      <look set='1' id='descrizione' tag='unt'/>
    </field>
    <field set='2' post='S' id='data' label='Data' type='date'/>
    <field set='3' post='S' id='note' label='Note' type='string' length='100'/>
    <field set='4' post='S' id='rif' label='Riferimento' type='select'>
      <option value='o1' selected>opzione1</option>
      <option value='o2'>opzione2</option>
    </field>
  </tbledit>

  produce questo html:
  <TR>
    <TD>Reparto</TD><TD><INPUT set="0" post="S" id="codice" onChange="fChkFld('number',true)"><INPUT set="1" id="descrizione" tag="unt" readonly=""><INPUT type="button" class='lookup' value="Elenco" title="Cerca in elenco" onClick="fLh(frm.action,'unt',codice,descrizione)"></TD>
  </TR>
  <TR>
    <TD>Data</TD><TD><INPUT set="2" id="data" onChange="fChkFld('date',false)"></TD>
  </TR>
  <TR>
    <TD>Note</TD><TD><INPUT set="3" id="note" onChange="fChkFld('string',false)"></TD>
  </TR>
  <TR>
    <TD>Riferimento</TD><TD><SELECT set="4" post="S" id="rif">
                               <option value='o1' selected>opzione1</option>
                               <option value='o2'>opzione2</option>
                            </SELECT></TD>
  </TR>
-->

<xsl:template match="/">
  <xsl:for-each select="tbledit/field">
    <TR><TD><xsl:value-of select="@label"/></TD><TD>
    <xsl:choose>
      <xsl:when test="@type='select'">
        <SELECT>
        <xsl:attribute name="set"><xsl:value-of select="@set"/></xsl:attribute>
        <xsl:if test="@post">
          <xsl:attribute name="post"><xsl:value-of select="@post"/></xsl:attribute>
        </xsl:if>
        <xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
        <xsl:apply-templates select="option"/>
        </SELECT>
      </xsl:when>
      <xsl:otherwise>
        <INPUT>
        <xsl:attribute name="set"><xsl:value-of select="@set"/></xsl:attribute>
        <xsl:if test="@post">
          <xsl:attribute name="post"><xsl:value-of select="@post"/></xsl:attribute>
        </xsl:if>
        <xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
        <xsl:if test="@readonly"><xsl:attribute name="readonly"/></xsl:if>
        <xsl:attribute name="onChange">fChkFld('<xsl:value-of select="@type"/>'<xsl:choose><xsl:when test="@mandatory">,true)</xsl:when><xsl:otherwise>,false)</xsl:otherwise></xsl:choose></xsl:attribute>
        <xsl:if test="@length"><xsl:attribute name="maxlength"><xsl:value-of select="@length"/></xsl:attribute></xsl:if>
        <xsl:if test="@type='number'"><xsl:attribute name="size">12</xsl:attribute></xsl:if>
        <xsl:if test="@type='string'"><xsl:attribute name="size">50</xsl:attribute></xsl:if>
        <xsl:if test="@type='icstring'"><xsl:attribute name="size">50</xsl:attribute></xsl:if>
        <xsl:if test="@type='date'"><xsl:attribute name="size">12</xsl:attribute></xsl:if>
        </INPUT>
        <xsl:apply-templates select="look"/>
      </xsl:otherwise>
      </xsl:choose>
    </TD></TR>
  </xsl:for-each>
</xsl:template>

<xsl:template match="look">
<INPUT maxLength='100' size='40'>
<xsl:attribute name="set"><xsl:value-of select="@set"/></xsl:attribute>
<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
<xsl:attribute name="tag"><xsl:value-of select="@tag"/></xsl:attribute>
</INPUT>
<INPUT type='button' class='lookup' value='Elenco' title='Cerca in elenco'>
<xsl:attribute name="onClick">fLookDlg(frm.action,'<xsl:value-of select="@tag"/>',<xsl:value-of select="../@id"/>,<xsl:value-of select="@id"/>)</xsl:attribute>
</INPUT>
</xsl:template>

<xsl:template match="option">
<OPTION>
<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
<xsl:value-of select="."/>
</OPTION>
</xsl:template>

</xsl:stylesheet>
